==> foundry_platform_sdk-0.49.0.tar.gz: foundry_platform_sdk-0.49.0/foundry/v1/ontologies/errors/_linked_object_not_found.py <==
#  Copyright 2024 Palantir Technologies, Inc.
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.


from __future__ import annotations

from dataclasses import dataclass
from typing import Dict
from typing import Literal

import pydantic
from typing_extensions import TypedDict

from foundry._errors import PalantirRPCException
from foundry.v1.ontologies.models._link_type_api_name import LinkTypeApiName
from foundry.v1.ontologies.models._object_type_api_name import ObjectTypeApiName
from foundry.v1.ontologies.models._primary_key_value import PrimaryKeyValue
from foundry.v1.ontologies.models._property_api_name import PropertyApiName


class LinkedObjectNotFoundParameters(TypedDict):
    """The linked object with the given primary key is not found, or the user does not have access to it."""

    __pydantic_config__ = {"extra": "allow"}  # type: ignore

    linkType: LinkTypeApiName

    linkedObjectType: ObjectTypeApiName

    linkedObjectPrimaryKey: Dict[PropertyApiName, PrimaryKeyValue]


@dataclass
class LinkedObjectNotFound(PalantirRPCException):
    name: Literal["LinkedObjectNotFound"]
    parameters: LinkedObjectNotFoundParameters
    error_instance_id: str


__all__ = ["LinkedObjectNotFound"]

==> foundry_platform_sdk-0.91.0.tar.gz: foundry_platform_sdk-0.91.0/foundry/v1/ontologies/errors/_linked_object_not_found.py <==
#  Copyright 2024 Palantir Technologies, Inc.
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.


from __future__ import annotations

from dataclasses import dataclass
from typing import Dict
from typing import Literal

from typing_extensions import TypedDict

from foundry._errors import NotFoundError
from foundry.v1.ontologies.models._link_type_api_name import LinkTypeApiName
from foundry.v1.ontologies.models._object_type_api_name import ObjectTypeApiName
from foundry.v1.ontologies.models._primary_key_value import PrimaryKeyValue
from foundry.v1.ontologies.models._property_api_name import PropertyApiName


class LinkedObjectNotFoundParameters(TypedDict):
    """The linked object with the given primary key is not found, or the user does not have access to it."""

    __pydantic_config__ = {"extra": "allow"}  # type: ignore

    linkType: LinkTypeApiName

    linkedObjectType: ObjectTypeApiName

    linkedObjectPrimaryKey: Dict[PropertyApiName, PrimaryKeyValue]


@dataclass
class LinkedObjectNotFound(NotFoundError):
    name: Literal["LinkedObjectNotFound"]
    parameters: LinkedObjectNotFoundParameters
    error_instance_id: str


__all__ = ["LinkedObjectNotFound"]
